@@ -2,7 +2,7 @@
 from enum import Enum
 
 
-class Framework (Enum, str):
+class Framework (str, Enum):
     huggingface = 'HUGGING_FACE'
     sklearn = 'SKLEARN'
     pytorch = 'PYTORCH'
@@ -10,27 +10,27 @@ class Framework (Enum, str):
     xgboost = 'XGBOOST'
 
 
-class Type (Enum, str):
+class Type (str, Enum):
     tabular = 'TABULAR'
     image = 'IMAGE'
     npl = 'NPL'
     other = 'OTHER'
 
 
-class Implementation (Enum, str):
+class Implementation (str, Enum):
     py37 = 'py37'
     py38 = 'py38'
     py39 = 'py39'
 
 
-class ModelType (Enum, str):
+class ModelType (str, Enum):
     tabular = 'TABULAR'
     image = 'IMAGE'
     npl = 'NPL'
     other = 'OTHER'
 
 
-class Server(Enum, str):
+class Server(str, Enum):
     standard_micro = 'STANDARD_MICRO'
     standard_small = 'STANDARD_SMALL'
     standard_medium = 'STANDARD_MEDIUM'
@@ -39,3 +39,14 @@ class Server(Enum, str):
     cpu_optimized_large = 'CPU_OPTIMIZED_LARGE'
     gpu_optimized_xlarge = 'GPU_OPTIMIZED_XLARGE'
     gpu_optimized_2xlarge = 'GPU_OPTIMIZED_2XLARGE'
+
+
+class MonitorSchemaType(str, Enum):
+    STRING = 'STRING'
+    INT = 'INT'
+    FLOAT = 'FLOAT'
+
+
+class MonitorPredictionType(str, Enum):
+    CATEGORICAL = 'CATEGORICAL'
+    NUMERIC = 'NUMERIC'
